<?xml version="1.0" ?><!DOCTYPE TS><TS language="nb" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Uttryksfeil</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Enkel modus</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Vitenskapelig modus</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Deepin Kalkulator</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Deepin Kalkulator er en enkel og brukervennlig kalkulator for skrivebordet. Den kan addisjon, subtraksjon, multiplikasjon og divisjon.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Uttryksfeil</translation>
    </message>
</context>
</TS>